#
# spec file for package diffutils
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           diffutils
Url:            http://www.gnu.org/software/diffutils/
Provides:       diff
Obsoletes:      diff
PreReq:         %{install_info_prereq}
Version:        3.3
Release:        9.5
Summary:        GNU diff Utilities
License:        GFDL-1.2 and GPL-3.0+
Group:          Productivity/Text/Utilities
Source:         http://ftp.gnu.org/gnu/%{name}/%{name}-%{version}.tar.xz
Source1:        http://ftp.gnu.org/gnu/%{name}/%{name}-%{version}.tar.xz.sig
# http://savannah.gnu.org/project/memberlist-gpgkeys.php?group=diffutils
Source2:        %name.keyring
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
# will be check by source service
#BuildRequires:  gpg-offline
BuildRequires:  xz

%description
The GNU diff utilities find differences between files. diff is used to
make source code patches, for instance.

%prep
%setup -q

%build
%configure
make %{?_smp_mflags}

%check
make check

%install
%makeinstall
gzip -9 %{buildroot}%{_infodir}/%{name}.info

%post
%install_info --info-dir=%{_infodir} %{_infodir}/%{name}.info.gz

%postun
%install_info_delete --info-dir=%{_infodir} %{_infodir}/%{name}.info.gz

%files
%defattr(-,root,root)
%doc AUTHORS COPYING NEWS README THANKS
%{_bindir}/cmp
%{_bindir}/diff
%{_bindir}/diff3
%{_bindir}/sdiff
%doc %{_infodir}/%{name}.info.gz
%doc %{_mandir}/man1/*.gz

%changelog
* Fri Dec  6 2013 pth@suse.de
- Diffutils has a testsuite so run it.
* Fri Jun 21 2013 meissner@suse.com
- disable gpg key checking to avoid build cycles. will be
  done by source service
* Fri Apr  5 2013 meissner@suse.com
- add gpg key checking, keyring from savannah
* Fri Apr  5 2013 jslaby@suse.com
- Update to 3.3:
  * add --no-dereference
  * -N works with - (stdin) as input
  * many fixes
  * many cleanups (in docco too)
- remove: config-guess-sub-update.patch
- remove: diffutils-stdio.in.patch
* Mon Mar 25 2013 mmeister@suse.com
- Added url as source.
  Please see http://en.opensuse.org/SourceUrls
* Sat Feb  2 2013 schwab@suse.de
- Update config.guess/sub for aarch64
* Tue Jul 17 2012 aj@suse.de
- Fix build with missing gets declaration (glibc 2.16)
* Mon Feb 27 2012 jslaby@suse.de
- Update to 3.2:
  * diff: --ignore-file-name-case now applies at top level too
  * diff, sdiff: new option --ignore-trailing-space
  * maint: avoid new "make sytnax-check" failure
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
  (cf. packaging guidelines)
* Sat Aug 13 2011 pth@suse.de
- Update to 3.1:
  + Bug fixes
  - diff no longer reports spurious differences merely because two
    entries in the same directory have names that compare equal in
    the current locale, or compare equal because --ignore-file-name-case
    was given.
* Sun Sep 19 2010 vuntz@opensuse.org
- Update to version 3.0:
  + Bug fixes
  - diff once again prints the required "\ No newline at end of
    file" line when at least one input lacks a newline-at-EOF and
    the final hunk plus context-length aligns exactly with the end
    of the newline-lacking file.
    [bug introduced between 2.8.7 and 2.9]
  + Changes in behavior
  - In context-style diffs, diff prints a portion of a preceding
    "function" line for each hunk, with --show-function-line=RE
    (-F) or --show-c-function (-p).  Now, it trims leading blanks
    from such lines before extracting a prefix.  This is useful
    especially when a function line is so far indented that the
    name itself would be truncated or not included in the
    limited-width substring that diff appends.
  - diff once again reports a difference with the diagnostic
    "Binary files A and B differ" when at least one of the files
    appears to be binary.  From 2.8.4 through diffutils-2.9, it
    printed "Files A and B differ".
- Changes from version 2.9:
  + New features
  - New diff option --suppress-blank-empty.
  - Bring back support for `diff -NUM', where NUM is a number,
    even when conforming to POSIX 1003.1-2001. This change
    reverts to the behavior of GNU diff 2.7 and earlier. This is
    a change only when conforming to POSIX 1003.1-2001; there is
    no effect when conforming to older POSIX versions.
  - sdiff now understands '1' and '2' as synonyms for 'l' and
    'r'.
  + Changes in behavior
  - sdiff and diff3 now invoke diff, not $(bindir)/diff
  + Administrivia
  - updated gnulib support
- Drop diffutils-no_binary_mode.patch: fixed upstream.
- Drop diffutils-2.8.1-i18n-0.2.patch: this doesn't apply anymore,
  the only reference I can guess about it goes back to 2004, and
  commit 8983b8d9 upstream is about handling multibyte characters
  in side-by-side format. So I'm assuming it's fixed. This also
  means we can drop the call to autoreconf.
- Drop diffutils-2.8.7-autoconf.patch: this is not needed anymore.
- Remove AutoReqProv: it's default now.
- Stop touching the main pages in %%build.
- Use %%configure and %%makeinstall macros.
* Fri Aug 20 2010 pth@novell.com
- Only do freopen if O_BINARY is true.
* Mon Jun 28 2010 jengelh@medozas.de
- use %%_smp_mflags
* Sat Feb 13 2010 rguenther@suse.de
- fix stack limit autoconf check
* Mon Dec  7 2009 jengelh@medozas.de
- enable parallel building
* Thu Jan 10 2008 schwab@suse.de
- Update to head of trunk.
  * New diff option --suppress-blank-empty.
  * Bring back support for `diff -NUM', where NUM is a number,
    even when conforming to POSIX 1003.1-2001.  This change reverts to
    the behavior of GNU diff 2.7 and earlier.  This is a change only
    when conforming to POSIX 1003.1-2001; there is no effect when
    conforming to older POSIX versions.
    This change is in response to decisions taken in the January 2005
    Austin Group standardization meeting.  For more details, please see
    "Utility Syntax Guidelines" in the Minutes of the January 2005
    Meeting <http://www.opengroup.org/austin/docs/austin_239.html>.
  * sdiff now understands '1' and '2' as synonyms for 'l' and 'r'.
* Mon Nov 27 2006 rguenther@suse.de
- removed help2man BuildRequires again.  Instead prevent patches
  from invalidating the shipped manpages.
* Thu Oct  5 2006 mjancar@suse.cz
- readd help2man to BuildRequires (needed to build manpages)
* Fri Aug 11 2006 schwab@suse.de
- Update cmp patch [#198332].
* Mon Jul 24 2006 rguenther@suse.de
- diffutils does not need help2man.
* Fri Mar 10 2006 schwab@suse.de
- Fix output of EOF message when stdout is redirected to /dev/null.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Sep 15 2004 schwab@suse.de
- Readd mbrtowc check [#45308].
* Tue May  4 2004 schwab@suse.de
- Update to diffutils 2.8.7.
* Tue Apr 13 2004 schwab@suse.de
- Update to diffutils 2.8.6.
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Wed Oct 15 2003 schwab@suse.de
- Update to diffutils 2.8.4.
* Mon May 12 2003 schwab@suse.de
- Add %%defattr.
* Thu Apr 24 2003 ro@suse.de
- fix install_info --delete call and move from preun to postun
* Mon Apr  7 2003 schwab@suse.de
- Only delete info entries when removing last version.
* Thu Feb  6 2003 schwab@suse.de
- Use %%install_info.
* Thu Sep  5 2002 schwab@suse.de
- Avoid rebuilding manpage [#18930].
* Tue Aug 20 2002 schwab@suse.de
- Add i18n patches.
* Mon Apr  8 2002 schwab@suse.de
- Update to diffutils 2.8.1.
  * Documentation fixes.
* Thu Mar 28 2002 schwab@suse.de
- Update to diffutils 2.8.
* Fri Oct  5 2001 schwab@suse.de
- Update to diffutils 2.7.2.
* Sat Jan 13 2001 schwab@suse.de
- Fix last change to close resource leaks.
* Sat Jan 13 2001 draht@suse.de
- tmpfile security problem fixed using mkstemp().
* Sun Dec  3 2000 schwab@suse.de
- diff: Fix a corner case in handling of directories.
- sdiff: Fix reading of split lines.
* Tue Oct 24 2000 schwab@suse.de
- Renamed from diff.
* Fri Sep  8 2000 schwab@suse.de
- Switch to BuildRoot.
- Add group tag.
- Use %%{_infodir}.
* Tue Jan 18 2000 schwab@suse.de
- /usr/info -> /usr/share/info
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Wed Sep  8 1999 schwab@suse.de
- specfile cleanup
* Fri Dec 18 1998 ro@suse.de
- dont use m486 on alpha :-)
* Thu Jan  2 1997 florian@suse.de
  bug-fix for sdiff
